@@ -23,7 +23,7 @@ def dec(args):
     
 
 def openJDGUI(args):
-    openGUI(None)
+    openGUI(args.input)
 
 def run():
     parser = argparse.ArgumentParser(prog="skyeye")
@@ -39,11 +39,12 @@ def run():
     scan_parser.set_defaults(func=scan)
     
     decompiling_parser = subparsers.add_parser('decompiling',help="反编译APK")
-    decompiling_parser.add_argument("-i","--input", type=str, help="输入扫描的APK路径",metavar="")
+    decompiling_parser.add_argument("-i","--input", type=str, help="目标APK路径",metavar="")
     decompiling_parser.add_argument("-o","--output", type=str,nargs='?', help="输出结果的文件夹路径",metavar="")
     decompiling_parser.set_defaults(func=dec)
     
     class_gui_parser = subparsers.add_parser('jd',help="打开JD-GUI工具")
+    class_gui_parser.add_argument("-i","--input", type=str, help="目标class文件路径 或者 class文件夹路径",metavar="")
     class_gui_parser.set_defaults(func=openJDGUI)
     
     args = parser.parse_args()
